"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDirtyFieldValidation = useDirtyFieldValidation;

var _react = require("react");

var _useValidation = require("./useValidation");

var _dirtyInfo = require("../dirtyInfo");

function useDirtyFieldValidation(rules, options = {}, deps = []) {
  const [dirtyOnly, setDirtyOnly] = (0, _react.useState)(true);
  const isDirtyFilter = (0, _react.useCallback)(context => {
    if (!context.dirtyInfo) {
      return true;
    }

    return _dirtyInfo.dirtyInfo.isPropertyDirty(context.fieldPath.join("."), context.dirtyInfo) ? true : false;
  }, []);
  const [validation, validate, reset] = (0, _useValidation.useValidation)(rules, { ...options,
    fieldFilterFunc: isDirtyFilter
  }, [...deps]);
  return [validation, // Validate
  (0, _react.useCallback)((model, dirtyInfo) => {
    if (!dirtyInfo) {
      setDirtyOnly(false);
    }

    return validate(model, {
      dirtyInfo: dirtyOnly ? dirtyInfo : undefined
    });
  }, [validate, dirtyOnly]), // Reset
  (0, _react.useCallback)(() => {
    setDirtyOnly(true);
    reset();
  }, [reset])];
}