"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useValidation = useValidation;

var _react = require("react");

var _pureValidations = require("@totalsoft/pure-validations");

function useValidation(rules, {
  isLogEnabled = true,
  logger = console,
  fieldFilterFunc = undefined
} = {}, deps = []) {
  const [validation, setValidation] = (0, _react.useState)(_pureValidations.Validation.Success());
  const validator = (0, _react.useMemo)(() => {
    let newValidator = rules;

    if (isLogEnabled) {
      newValidator = (0, _pureValidations.logTo)(logger)(newValidator);
    }

    if (fieldFilterFunc) {
      newValidator = (0, _pureValidations.filterFields)(fieldFilterFunc)(newValidator);
    }

    return newValidator;
  }, [rules, isLogEnabled, logger, fieldFilterFunc, ...deps]); // eslint-disable-line react-hooks/exhaustive-deps

  return [validation, // Validate
  (0, _react.useCallback)((model, context) => {
    const validation = (0, _pureValidations.validate)(validator, model, context);
    setValidation(validation);
    return (0, _pureValidations.isValid)(validation);
  }, [validator]), // Reset
  (0, _react.useCallback)(() => {
    setValidation(_pureValidations.Validation.Success());
  }, [])];
}